This function extends the ABC model with statistical significance testing to evaluate the strength of discovered connections.
abc_model_sig(
co_matrix,
a_term,
c_term = NULL,
a_type = NULL,
c_type = NULL,
min_score = 0.1,
n_results = 100,
n_permutations = 1000,
scoring_method = c("multiplication", "average", "combined", "jaccard")
)A data frame with ranked discovery results and p-values.
A co-occurrence matrix produced by create_cooccurrence_matrix().
Character string, the source term (A).
Character string, the target term (C). If NULL, all potential C terms will be evaluated.
Character string, the entity type for A terms. If NULL, all types are considered.
Character string, the entity type for C terms. If NULL, all types are considered.
Minimum score threshold for results.
Maximum number of results to return.
Number of permutations for significance testing.
Method to use for scoring ABC connections.