Learn R Programming

LBDiscover (version 0.1.0)

get_term_vars: Extract term variations from text corpus

Description

This function identifies variations of a primary term within a corpus of articles.

Usage

get_term_vars(articles, primary_term, text_col = "abstract")

Value

A character vector of unique term variations, sorted by length

Arguments

articles

A data frame containing article data with text columns

primary_term

The primary term to find variations of

text_col

Name of the column containing the text to search